@@ -15,50 +15,51 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ev-file-helpers.c,v 1.4 2005/07/07 09:34:45 marco Exp $
+ *  $Id: ev-file-helpers.c,v 1.6 2006/11/15 11:33:09 carlosgc Exp $
  */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
-#include <sys/stat.h>
-#include <glib.h>
-#include <libgnome/gnome-init.h>
+#include <stdlib.h>
+#include <sys/types.h>
 #include <unistd.h>
+#include <string.h>
+#include <glib.h>
+#include <glib/gstdio.h>
+#include <libgnome/gnome-init.h>
+#include <libgnomevfs/gnome-vfs-uri.h>
+#include <libgnomevfs/gnome-vfs-utils.h>
+#include <libgnomevfs/gnome-vfs-ops.h>
+#include <libgnomevfs/gnome-vfs-xfer.h>
 
 #include "ev-file-helpers.h"
 
-static char *dot_dir = NULL;
-static char *tmp_dir = NULL;
-static int  count = 0;
+static gchar *dot_dir = NULL;
+static gchar *tmp_dir = NULL;
+static gint   count = 0;
 
 static gboolean
 ensure_dir_exists (const char *dir)
 {
-	if (g_file_test (dir, G_FILE_TEST_IS_DIR) == FALSE)
-	{
-		if (g_file_test (dir, G_FILE_TEST_EXISTS) == TRUE)
-		{
-			g_warning ("%s exists, please move it out of the way.", dir);
-			return FALSE;
-		}
+	if (g_file_test (dir, G_FILE_TEST_IS_DIR))
+		return TRUE;
+	
+	if (g_mkdir (dir, 488) == 0)
+		return TRUE;
 
-		if (mkdir (dir, 488) != 0)
-		{
-			g_warning ("Failed to create directory %s.", dir);
-			return FALSE;
-		}
-	}
-
-	return TRUE;
+	if (errno == EEXIST)
+		return g_file_test (dir, G_FILE_TEST_IS_DIR);
+	
+	g_warning ("Failed to create directory %s: %s", dir, strerror (errno));
+	return FALSE;
 }
 
-const char *
+const gchar *
 ev_dot_dir (void)
 {
-	if (dot_dir == NULL)
-	{
+	if (dot_dir == NULL) {
 		gboolean exists;
 
 		dot_dir = g_build_filename (gnome_user_dir_get (),
@@ -66,12 +67,33 @@ ev_dot_dir (void)
 					    NULL);
 
 		exists = ensure_dir_exists (dot_dir);
-		g_assert (exists);
+		if (!exists)
+			exit (1);
 	}
 
 	return dot_dir;
 }
 
+const gchar *
+ev_tmp_dir (void)
+{
+	if (tmp_dir == NULL) {
+		gboolean exists;
+		gchar   *dirname;
+
+		dirname = g_strdup_printf ("evince-%u", getpid ());
+		tmp_dir = g_build_filename (g_get_tmp_dir (),
+					    dirname,
+					    NULL);
+		g_free (dirname);
+
+		exists = ensure_dir_exists (tmp_dir);
+		g_assert (exists);
+	}
+
+	return tmp_dir;
+}
+
 void
 ev_file_helpers_init (void)
 {
@@ -81,7 +103,7 @@ void
 ev_file_helpers_shutdown (void)
 {	
 	if (tmp_dir != NULL)	
-		rmdir (tmp_dir);
+		g_rmdir (tmp_dir);
 
 	g_free (tmp_dir);
 	g_free (dot_dir);
@@ -90,37 +112,56 @@ ev_file_helpers_shutdown (void)
 	tmp_dir = NULL;
 }
 
-gchar* 
+gchar * 
 ev_tmp_filename (void)
 {
 	gchar *basename;
 	gchar *filename = NULL;
 
-	if (tmp_dir == NULL) {
-		gboolean exists;
-		gchar   *dirname;
-		
-		dirname = g_strdup_printf ("evince-%u", getpid());
-		tmp_dir = g_build_filename (g_get_tmp_dir (),
-					    dirname,
-					    NULL);
-		g_free (dirname);
-
-		exists = ensure_dir_exists (tmp_dir);
-		g_assert (exists);
-	}
-	
-	
 	do {
 		if (filename != NULL)
 			g_free (filename);
 			
 		basename = g_strdup_printf ("document-%d", count ++);
 		
-		filename = g_build_filename (tmp_dir, basename, NULL);
+		filename = g_build_filename (ev_tmp_dir (),
+					     basename, NULL);
 		
 		g_free (basename);
 	} while (g_file_test (filename, G_FILE_TEST_EXISTS));
 			
 	return filename;
 }
+
+gboolean
+ev_xfer_uri_simple (const char *from,
+		    const char *to,
+		    GError     **error)
+{
+	GnomeVFSResult result;
+	GnomeVFSURI *source_uri;
+	GnomeVFSURI *target_uri;
+	
+	if (!from)
+		return FALSE;
+	
+	source_uri = gnome_vfs_uri_new (from);
+	target_uri = gnome_vfs_uri_new (to);
+
+	result = gnome_vfs_xfer_uri (source_uri, target_uri, 
+				     GNOME_VFS_XFER_DEFAULT | GNOME_VFS_XFER_FOLLOW_LINKS,
+				     GNOME_VFS_XFER_ERROR_MODE_ABORT,
+				     GNOME_VFS_XFER_OVERWRITE_MODE_REPLACE,
+				     NULL,
+				     NULL);
+	gnome_vfs_uri_unref (target_uri);
+	gnome_vfs_uri_unref (source_uri);
+    
+	if (result != GNOME_VFS_OK)
+		g_set_error (error,
+			     G_FILE_ERROR,
+			     G_FILE_ERROR_FAILED,
+			     gnome_vfs_result_to_string (result));
+	return (result == GNOME_VFS_OK);
+
+}
