@@ -32,6 +32,7 @@
 #ifndef HAVE_GTK_RECENT
 #include "egg-recent-model.h"
 #endif
+#include "totem-scrsaver.h"
 
 G_BEGIN_DECLS
 
@@ -53,9 +54,13 @@ struct _EvApplication {
 	gchar *toolbars_file;
 	
 	EggToolbarsModel *toolbars_model;
+	EggToolbarsModel *preview_toolbars_model;
+	
 #ifndef HAVE_GTK_RECENT
 	EggRecentModel  *recent_model;
 #endif
+
+	TotemScrsaver *scr_saver;
 	
 	gchar *last_chooser_uri;
 };
@@ -71,6 +76,7 @@ void	          ev_application_shutdown	     (EvApplication   *application);
 
 
 gboolean          ev_application_open_window         (EvApplication   *application,
+						      GHashTable      *args,
 						      guint32          timestamp,
 						      GError         **error);
 gboolean          ev_application_open_uri            (EvApplication   *application,
@@ -80,15 +86,19 @@ gboolean          ev_application_open_uri            (EvApplication   *applicati
 						      GError         **error);
 void              ev_application_open_uri_at_dest    (EvApplication   *application,
 						      const char      *uri,
+						      GdkScreen       *screen,
 						      EvLinkDest      *dest,
 						      EvWindowRunMode  mode,
+						      gboolean         unlink_temp_file,
 						      guint32          timestamp);
 void	          ev_application_open_uri_list       (EvApplication   *application,
 		  			              GSList          *uri_list,
+						      GdkScreen       *screen,
     						      guint32          timestamp);
 GList		 *ev_application_get_windows	     (EvApplication   *application);
 
-EggToolbarsModel *ev_application_get_toolbars_model  (EvApplication   *application);
+EggToolbarsModel *ev_application_get_toolbars_model  (EvApplication   *application, 
+						      gboolean preview);
 void              ev_application_save_toolbars_model (EvApplication   *application);
 #ifndef HAVE_GTK_RECENT
 EggRecentModel   *ev_application_get_recent_model    (EvApplication   *application);
@@ -96,7 +106,8 @@ EggRecentModel   *ev_application_get_recent_model    (EvApplication   *applicati
 void 		  ev_application_set_chooser_uri     (EvApplication   *application, 
 						      const gchar     *uri);
 const gchar	 *ev_application_get_chooser_uri     (EvApplication   *application);
-
+void		  ev_application_screensaver_enable  (EvApplication   *application);
+void		  ev_application_screensaver_disable (EvApplication   *application);
 G_END_DECLS
 
 #endif /* !EV_APPLICATION_H */
