@@ -7,7 +7,7 @@
 #include "ev-document-fonts.h"
 #include "ev-selection.h"
 #include "ev-async-renderer.h"
-#include "ev-ps-exporter.h"
+#include "ev-file-exporter.h"
 #include "ev-window.h"
 
 #include <glib/gstdio.h>
@@ -316,6 +316,8 @@ ev_job_render_run (EvJobRender *job)
 		g_signal_connect (EV_JOB (job)->document, "render_finished",
 				  G_CALLBACK (render_finished_cb), job);
 	} else {
+		ev_document_fc_mutex_lock ();
+		
 		job->pixbuf = ev_document_render_pixbuf (EV_JOB (job)->document, job->rc);
 		if (job->include_links && EV_IS_DOCUMENT_LINKS (EV_JOB (job)->document))
 			job->link_mapping =
@@ -337,7 +339,8 @@ ev_job_render_run (EvJobRender *job)
 								   job->rc,
 								   &(job->selection_points));
 		}
-
+		
+		ev_document_fc_mutex_unlock ();
 		EV_JOB (job)->finished = TRUE;
 	}
 
@@ -406,7 +409,9 @@ ev_job_fonts_run (EvJobFonts *job)
 	ev_document_doc_mutex_lock ();
 	
 	fonts = EV_DOCUMENT_FONTS (EV_JOB (job)->document);
+	ev_document_fc_mutex_lock ();
 	job->scan_completed = !ev_document_fonts_scan (fonts, 20);
+	ev_document_fc_mutex_unlock ();
 	
 	EV_JOB (job)->finished = TRUE;
 
@@ -527,11 +532,16 @@ ev_job_xfer_run (EvJobXfer *job)
 }
 
 EvJob *
-ev_job_print_new (EvDocument   *document,
-		  EvPrintRange *ranges,
-		  gint          n_ranges,
-		  gdouble       width,
-		  gdouble       height)
+ev_job_print_new (EvDocument    *document,
+		  const gchar   *format,
+		  gdouble        width,
+		  gdouble        height,
+		  EvPrintRange  *ranges,
+		  gint           n_ranges,
+		  EvPrintPageSet page_set,
+		  gint           copies,
+		  gdouble        collate,
+		  gdouble        reverse)
 {
 	EvJobPrint *job;
 
@@ -539,15 +549,23 @@ ev_job_print_new (EvDocument   *document,
 
 	EV_JOB (job)->document = g_object_ref (document);
 
+	job->format = format;
+	
 	job->temp_file = NULL;
 	job->error = NULL;
 
-	job->ranges = ranges;
-	job->n_ranges = n_ranges;
-	
 	job->width = width;
 	job->height = height;
 
+	job->ranges = ranges;
+	job->n_ranges = n_ranges;
+
+	job->page_set = page_set;
+	
+	job->copies = copies;
+	job->collate = collate;
+	job->reverse = reverse;
+	
 	return EV_JOB (job);
 }
 
@@ -589,8 +607,8 @@ ev_print_job_get_last_page (EvJobPrint *job)
 }
 
 static gboolean
-ev_print_job_print_page (EvJobPrint *job,
-			 gint        page)
+ev_print_job_print_page_in_range (EvJobPrint *job,
+				  gint        page)
 {
 	gint i;
 
@@ -603,6 +621,33 @@ ev_print_job_print_page (EvJobPrint *job,
 	return FALSE;
 }
 
+static gboolean
+ev_print_job_print_page_in_set (EvJobPrint *job,
+				gint        page)
+{
+	switch (job->page_set) {
+	        case EV_PRINT_PAGE_SET_EVEN:
+			return page % 2 == 0;
+	        case EV_PRINT_PAGE_SET_ODD:
+			return page % 2 != 0;
+	        case EV_PRINT_PAGE_SET_ALL:
+			return TRUE;
+	}
+
+	return FALSE;
+}
+
+static void
+ev_job_print_do_page (EvJobPrint *job, gint page)
+{
+	EvDocument      *document = EV_JOB (job)->document;
+	EvRenderContext *rc;
+
+	rc = ev_render_context_new (0, page, 1.0);
+	ev_file_exporter_do_page (EV_FILE_EXPORTER (document), rc);
+	g_object_unref (rc);
+}
+
 void
 ev_job_print_run (EvJobPrint *job)
 {
@@ -611,6 +656,7 @@ ev_job_print_run (EvJobPrint *job)
 	gint        last_page;
 	gint        first_page;
 	gint        i;
+	gchar      *filename;
 	
 	g_return_if_fail (EV_IS_JOB_PRINT (job));
 
@@ -621,8 +667,10 @@ ev_job_print_run (EvJobPrint *job)
 	if (job->error)
 		g_error_free (job->error);
 	job->error = NULL;
-	
-	fd = g_file_open_tmp ("evince_print.ps.XXXXXX", &job->temp_file, &job->error);
+
+	filename = g_strdup_printf ("evince_print.%s.XXXXXX", job->format);
+	fd = g_file_open_tmp (filename, &job->temp_file, &job->error);
+	g_free (filename);
 	if (fd <= -1) {
 		EV_JOB (job)->finished = TRUE;
 		return;
@@ -632,31 +680,55 @@ ev_job_print_run (EvJobPrint *job)
 	last_page = ev_print_job_get_last_page (job);
 
 	ev_document_doc_mutex_lock ();
-	ev_ps_exporter_begin (EV_PS_EXPORTER (document),
-			      job->temp_file,
-			      MIN (first_page, last_page),
-			      MAX (first_page, last_page),
-			      job->width, job->height, FALSE);
+	ev_file_exporter_begin (EV_FILE_EXPORTER (document),
+				g_ascii_strcasecmp (job->format, "pdf") == 0 ?
+				EV_FILE_FORMAT_PDF : EV_FILE_FORMAT_PS,
+				job->temp_file,
+				MIN (first_page, last_page),
+				MAX (first_page, last_page),
+				job->width, job->height, FALSE);
 	ev_document_doc_mutex_unlock ();
 
-	for (i = first_page; i <= last_page; i++) {
-		EvRenderContext *rc;
-
-		if (job->n_ranges > 0 &&
-		    !ev_print_job_print_page (job, i))
-			continue;
+	for (i = 0; i < job->copies; i++) {
+		gint page, step;
 		
-		rc = ev_render_context_new (0, i, 1.0);
+		step = job->reverse ? -1 : 1;
+		page = job->reverse ? last_page : first_page;
+		
+		while ((job->reverse && (page >= first_page)) ||
+		       (!job->reverse && (page <= last_page))) {
+			gint n_pages = 1;
+			gint j;
 
-		ev_document_doc_mutex_lock ();
-		ev_ps_exporter_do_page (EV_PS_EXPORTER (document), rc);
-		ev_document_doc_mutex_unlock ();
+			if (job->n_ranges > 0 &&
+			    !ev_print_job_print_page_in_range (job, page)) {
+				page += step;
+				continue;
+			}
 
-		g_object_unref (rc);
+			if (!ev_print_job_print_page_in_set (job, page + 1)) {
+				page += step;
+				continue;
+			}
+
+			if (job->collate)
+				n_pages = job->copies;
+
+			for (j = 0; j < n_pages; j++) {
+				ev_document_doc_mutex_lock ();
+				ev_job_print_do_page (job, page);
+				ev_document_doc_mutex_unlock ();
+			}
+
+			page += step;
+		}
+
+		if (job->collate)
+			break;
 	}
 
 	ev_document_doc_mutex_lock ();
-	ev_ps_exporter_end (EV_PS_EXPORTER (document));
+	ev_file_exporter_end (EV_FILE_EXPORTER (document));
 	ev_document_doc_mutex_unlock ();
 
 	close (fd);
