@@ -43,13 +43,19 @@ typedef struct {
 	gint end;
 } EvPrintRange;
 
+typedef enum {
+	EV_PRINT_PAGE_SET_ALL,
+	EV_PRINT_PAGE_SET_EVEN,
+	EV_PRINT_PAGE_SET_ODD
+} EvPrintPageSet;
+
 typedef struct _EvWindow EvWindow;
 typedef struct _EvWindowClass EvWindowClass;
 typedef struct _EvWindowPrivate EvWindowPrivate;
 
 #define EV_TYPE_WINDOW			(ev_window_get_type())
 #define EV_WINDOW(object)		(G_TYPE_CHECK_INSTANCE_CAST((object), EV_TYPE_WINDOW, EvWindow))
-#define EV_WINDOW_CLASS(klass)		(G_TYPE_CHACK_CLASS_CAST((klass), EV_TYPE_WINDOW, EvWindowClass))
+#define EV_WINDOW_CLASS(klass)		(G_TYPE_CHECK_CLASS_CAST((klass), EV_TYPE_WINDOW, EvWindowClass))
 #define EV_IS_WINDOW(object)		(G_TYPE_CHECK_INSTANCE_TYPE((object), EV_TYPE_WINDOW))
 #define EV_IS_WINDOW_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE((klass), EV_TYPE_WINDOW))
 #define EV_WINDOW_GET_CLASS(object)	(G_TYPE_INSTANCE_GET_CLASS((object), EV_TYPE_WINDOW, EvWindowClass))
@@ -70,7 +76,8 @@ const char     *ev_window_get_uri         (EvWindow       *ev_window);
 void		ev_window_open_uri	  (EvWindow       *ev_window,
 					   const char     *uri,
 					   EvLinkDest     *dest,
-					   EvWindowRunMode mode);
+					   EvWindowRunMode mode,
+					   gboolean        unlink_temp_file);
 void            ev_window_goto_dest       (EvWindow       *ev_window,
 					   EvLinkDest     *dest);
 gboolean	ev_window_is_empty	  (const EvWindow *ev_window);
